@@ -20,6 +20,7 @@
 #include <QKeyEvent>
 #include <QPainter>
 #include <QPrintDialog>
+#include <QPrinter>
 #include <QPushButton>
 #include <QTimer>
 #include <QVBoxLayout>
@@ -61,8 +62,6 @@ KSMainWindow::KSMainWindow(Platform::GrabModes theGrabModes, Platform::ShutterMo
     , mClipboardImageAction(new QAction(this))
     , mSaveButton(new QToolButton(this))
     , mSaveMenu(new QMenu(this))
-    , mSaveAsAction(new QAction(this))
-    , mSaveAction(new QAction(this))
     , mMessageWidget(new KMessageWidget(this))
     , mToolsMenu(new QMenu(this))
     , mScreenRecorderToolsMenu(new QMenu(this))
@@ -153,7 +152,7 @@ void KSMainWindow::init()
             mAnnotateButton->setText(i18n("Annotate"));
         } else {
             mKSWidget->showAnnotator();
-            mAnnotateButton->setText(i18n("Annotation done"));
+            mAnnotateButton->setText(i18n("Annotation Done"));
         }
 
         mToolsButton->setEnabled(mAnnotatorActive);
@@ -389,7 +388,7 @@ void KSMainWindow::captureScreenshot(Spectacle::CaptureMode theCaptureMode, int
     delayAnimation->start();
 }
 
-void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap)
+void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap, bool showAnnotator)
 {
     mPixmapExists = !pixmap.isNull();
     if (mPixmapExists) {
@@ -404,7 +403,6 @@ void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap)
 #ifdef KIMAGEANNOTATOR_FOUND
     mAnnotateButton->setEnabled(mPixmapExists);
 #endif
-    mToolsButton->setEnabled(mPixmapExists);
     mSendToButton->setEnabled(mPixmapExists);
     mClipboardButton->setEnabled(mPixmapExists);
     mSaveButton->setEnabled(mPixmapExists);
@@ -417,6 +415,11 @@ void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap)
     if (mPixmapExists) {
         resize(QSize(windowWidth(pixmap), DEFAULT_WINDOW_HEIGHT));
     }
+    if (showAnnotator) {
+#ifdef KIMAGEANNOTATOR_FOUND
+        mAnnotateButton->click();
+#endif
+    }
 }
 
 void KSMainWindow::showPrintDialog()
