@@ -6,13 +6,13 @@
 #pragma once
 
 #include <QDialog>
-#include <QDialogButtonBox>
-#include <QFrame>
-#include <QMenu>
-#include <QStackedLayout>
-#include <QToolButton>
+class QDialogButtonBox;
+class QFrame;
+class QMenu;
+class QStackedLayout;
+class QToolButton;
 
-#include <KMessageWidget>
+class KMessageWidget;
 #include <KNS3/KMoreToolsMenuFactory>
 
 #include "SpectacleCommon.h"
@@ -22,6 +22,7 @@
 #include "KSWidget.h"
 #include "Platforms/Platform.h"
 
+#include <KMessageWidget>
 #include <memory>
 
 class KSMainWindow : public QDialog
@@ -63,7 +64,7 @@ private Q_SLOTS:
 
 public Q_SLOTS:
 
-    void setScreenshotAndShow(const QPixmap &pixmap);
+    void setScreenshotAndShow(const QPixmap &pixmap, bool showAnnotator);
     void imageSaved(const QUrl &location);
     void imageSavedAndCopied(const QUrl &location);
     void screenshotFailed();
@@ -104,6 +105,7 @@ private:
     Platform::ShutterModes mShutterModes;
     QTimer *mHideMessageWidgetTimer = nullptr;
     QStackedLayout *mStack = nullptr;
+    bool mPixmapExists = false;
 
 #ifdef KIMAGEANNOTATOR_FOUND
     QToolButton *const mAnnotateButton;
